==> h5p-7.x-1.13.tar.gz: h5p/modules/h5peditor/h5peditor/language/it.js <==
H5PEditor.language.core = {
  missingTranslation: "[Traduzione mancante :key]",
  loading: "Caricamento :type, si prega di attendere...",
  selectLibrary: "Seleziona la libreria che userai per i tuoi contenuti.",
  unknownFieldPath: "Impossibibile trovare :path.",
  notImageField: ":path non è un'immagine.",
  notImageOrDimensionsField: ":path non è un'immagine o dimensioni campo.",
  requiredProperty: ":property è richiesta e deve avere un valore.",
  onlyNumbers: "Il valore di :property può contenere solo numeri.",
  exceedsMax: "Il valore di :property eccede il massimo di :max.",
  exceedsMin: "Il valore di :property eccede il minimo di :min.",
  outOfStep: "Il valore di :property può essere modificato solo negli step di :step.",
  addFile: "Aggiungi file",
  removeFile: "Rimuovi file",
  confirmRemoval: "Sei sicuro di voler rimuovere questo :type?",
  changeFile: "Cambia file",
  semanticsError: "Errore semantico: :error",
  missingProperty: "Nel campo :index manca la sua proprietà :property.",
  expandCollapse: "Espandi/Collassa",
  addEntity: "Aggiungi :entity",
  tooLong: "Il valore del campo è troppo lungo, dovrebbe contenere al massimo :max lettere.",
  invalidFormat: "Il valore del campo contiene un formato non valido o caratteri non consentiti.",
  confirmChangeLibrary: "Sei sicuro di voler cambiare libreria?",
  moreLibraries: "Cerca <a href=\"http://h5p.org/content-types-and-applications\" target=\"_blank\">più tipi di contentuto</a> su h5p.org",
  commonFields: "Impostazioni e testi",
  commonFieldsDescription: "Da qui puoi modificare le impostazioni o tradurre testi utilizzati in questo contenuto.",
  uploading: "Caricamento, si prega di attendere...",
  noFollow: "Impossibile seguire il campo :path.",
  editCopyright: "Modifica copyright",
  close: "Chiudi",
  tutorialAvailable: "Tutorial disponibile",
  editMode: "Modalità modifica",
  listLabel: "Lista",
  uploadError: 'File Upload Error',
  fileToLarge: 'The file you are trying to upload might be too large.',
  noSemantics: 'Error, could not load the content type form.',
  editImage: 'Edit image',
  saveLabel: 'Save',
  cancelLabel: 'Cancel',
  resetToOriginalLabel: 'Reset to original',
  loadingImageEditor: 'Loading image editor, please wait...'
};

==> h5p-7.x-1.16.tar.gz: h5p/modules/h5peditor/h5peditor/language/it.js <==
H5PEditor.language.core = {
  missingTranslation: "[Traduzione mancante :key]",
  loading: "Caricamento :type, si prega di attendere...",
  selectLibrary: "Seleziona la libreria che userai per i tuoi contenuti.",
  unknownFieldPath: "Impossibibile trovare :path.",
  notImageField: ":path non è un'immagine.",
  notImageOrDimensionsField: ":path non è un'immagine o dimensioni campo.",
  requiredProperty: ":property è richiesta e deve avere un valore.",
  onlyNumbers: "Il valore di :property può contenere solo numeri.",
  exceedsMax: "Il valore di :property eccede il massimo di :max.",
  belowMin: "Il valore di :property eccede il minimo di :min.",
  outOfStep: "Il valore di :property può essere modificato solo negli step di :step.",
  addFile: "Aggiungi file",
  removeFile: "Rimuovi file",
  confirmRemoval: "Sei sicuro di voler rimuovere questo :type?",
  removeImage: 'Rimuovi immagine',
  confirmImageRemoval: 'Questo rimuoverà l\'immagine . Sei sicuro di voler procedere ?',
  changeFile: "Cambia file",
  changeLibrary: 'Cambiare tipo di contenuto',
  semanticsError: "Errore semantico: :error",
  missingProperty: "Nel campo :index manca la sua proprietà :property.",
  expandCollapse: "Espandi/Collassa",
  addEntity: "Aggiungi :entity",
  tooLong: "Il valore del campo è troppo lungo, dovrebbe contenere al massimo :max lettere.",
  invalidFormat: "Il valore del campo contiene un formato non valido o caratteri non consentiti.",
  confirmChangeLibrary: "Sei sicuro di voler cambiare libreria?",
  moreLibraries: "Cerca <a href=\"http://h5p.org/content-types-and-applications\" target=\"_blank\">più tipi di contentuto</a> su h5p.org",
  commonFields: "Impostazioni e testi",
  commonFieldsDescription: "Da qui puoi modificare le impostazioni o tradurre testi utilizzati in questo contenuto.",
  uploading: "Caricamento, si prega di attendere...",
  noFollow: "Impossibile seguire il campo :path.",
  editCopyright: "Modifica copyright",
  close: "Chiudi",
  tutorialAvailable: "Tutorial disponibile",
  editMode: "Modalità modifica",
  listLabel: "Lista",
  uploadError: 'File Upload Error',
  fileToLarge: 'The file you are trying to upload might be too large.',
  noSemantics: 'Error, could not load the content type form.',
  editImage: 'Edit image',
  saveLabel: 'Save',
  cancelLabel: 'Cancel',
  resetToOriginalLabel: 'Reset to original',
  loadingImageEditor: 'Loading image editor, please wait...'
};
